==> haskell-connection-0.2.8-118-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.2.8
id: connection-0.2.8-60CoESWDtkP8GOtdZUw1hW
key: connection-0.2.8-60CoESWDtkP8GOtdZUw1hW
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
abi: 04fa2801318029f598e4e0f7ab3ff491
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/connection-0.2.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/connection-0.2.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/connection-0.2.8
hs-libraries: HSconnection-0.2.8-60CoESWDtkP8GOtdZUw1hW
depends:
    base-4.12.0.0 byteable-0.1.1-9guyEXUUK503mzSnI32g2S
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    network-2.8.0.0-g7zeLS1MQKFu6rNI1xGwt
    socks-0.5.6-HDJSgBTlVbv1ZJ1dxx8gL0 tls-1.4.1-FpL0z7KZJreH7VtfsMhlVP
    x509-1.7.5-4UJhh5NPMuwB64nGGQQFaV
    x509-store-1.6.7-7LPaDQEBpr0B4joV4k4DuJ
    x509-system-1.6.6-EScLUDhSJ9d7PZDIfjWnvw
    x509-validation-1.6.11-36YkUpy4q60CofQpkCcSEP
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-connection-0.2.8-120-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-connection.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: connection
version: 0.2.8
id: connection-0.2.8-7XFC0C4DIj58PradlKb2Tw
key: connection-0.2.8-7XFC0C4DIj58PradlKb2Tw
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-connection
synopsis: Simple and easy network connections API
description:
    Simple network library for all your connection need.
    .
    Features: Really simple to use, SSL/TLS, SOCKS.
    .
    This library provides a very simple api to create sockets
    to a destination with the choice of SSL/TLS, and SOCKS.
category: Network
abi: e34f315be6aed9f1a449ce5d0eb1c51b
exposed: True
exposed-modules:
    Network.Connection
hidden-modules: Network.Connection.Types
import-dirs: /usr/lib/ghc-8.6.5/site-local/connection-0.2.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/connection-0.2.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/connection-0.2.8
hs-libraries: HSconnection-0.2.8-7XFC0C4DIj58PradlKb2Tw
depends:
    base-4.12.0.0 byteable-0.1.1-9guyEXUUK503mzSnI32g2S
    bytestring-0.10.8.2 containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    network-2.8.0.0-JWTbamlNgQDGa4CnHHLrSE
    socks-0.5.6-6M1kPcd4XavIdGlBGPLURZ tls-1.4.1-K2yPt49ylKFE5O8uL7p2rw
    x509-1.7.5-2xExHLJ3VNlBZRhBywKbfo
    x509-store-1.6.7-G986kl4ujQjFFn5YKMuPr5
    x509-system-1.6.6-Krj3F0KhQ3AI9FDpDCuEXy
    x509-validation-1.6.11-2U1hkNRxBAw4ERaFellGZN
haddock-interfaces: /usr/share/doc/haskell-connection/html/connection.haddock
haddock-html: /usr/share/doc/haskell-connection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
